/*
 
*** Audio Player Example 2 for ATE-550 from Antratek Electronics ***

Based on Arduino Sound library and WavePlayback example on arduino.cc. (= Example 1 for ATE-550)
 
Created in 2023 by André Veenstra

This example plays 6 audio tracks. At each push on test button or high at sensor input
one track is played. At the next push or high the next track is played, and so on.
The rotary switch is used to adjust volume and the LED is on during playing.
 
*/

#include <SD.h>
#include <ArduinoSound.h>

// filename of wave file to play
const char filename1[] = "track001.wav";
const char filename2[] = "track002.wav";
const char filename3[] = "track003.wav";
const char filename4[] = "track004.wav";
const char filename5[] = "track005.wav";
const char filename6[] = "track006.wav";


// variable representing the Wave File
SDWaveFile waveFile;

int counter = 0; //indicates which audio file is next
int test = 5; //number of pin with test button
int inputpin = 6; //number of pin to which input door sensor is connected
int led = 12; // number of pin with led
int prevteststate = 1; //previous test button state
int prevsensorstate = 0; //previous sensor status
int sensoractive = 0; //sensor was activated
int vol = 20; // sound volume
int bcd1 = 15; //pin 1 to 4 of BCD switch for volume
int bcd2 = 16;
int bcd4 = 17;
int bcd8 = 18;

void setup() {
// Open serial communications and wait for port to open:
// Serial.begin(9600);
// while (!Serial) {
// ; 
// }

 // initialize pins
 pinMode(LED_BUILTIN, OUTPUT); 
 pinMode(led, OUTPUT);
 pinMode(test, INPUT_PULLUP);
 pinMode(inputpin, INPUT);
 pinMode(bcd1, INPUT_PULLUP);
 pinMode(bcd2, INPUT_PULLUP);
 pinMode(bcd4, INPUT_PULLUP);
 pinMode(bcd8, INPUT_PULLUP);

 digitalWrite(LED_BUILTIN, HIGH); // to indicate power is on
 
 // setup the SD card, depending on your shield of breakout board
 // you may need to pass a pin number in begin for SS
// Serial.print("Initializing SD card...");
 if (!SD.begin(4)) {
// Serial.println("initialization failed!");
 digitalWrite(led, HIGH);
 while (1); // do nothing, led will stay on to indicate SD card is missing
 }
 else {
// Serial.println("initialization done.");
 digitalWrite(led, HIGH);
 delay(500); // short led flash indicates that player is initialized correctly
 digitalWrite(led, LOW);
 }
 // check if the I2S output can play the first wave file
 waveFile = SDWaveFile(filename1);
 if (!AudioOutI2S.canPlay(waveFile)) {
// Serial.println("unable to play wave file using I2S!");
 digitalWrite(led, HIGH);
 while (1); // do nothing, led will stay on to indicate valid file is missing
 }
}

 
void loop() {
 // check if playback is still going on
 if (!AudioOutI2S.isPlaying()) {
 // playback has stopped
 digitalWrite(led, LOW); // turn the LED off
// Serial.println("playback stopped");
 if (digitalRead(inputpin) == HIGH && prevsensorstate == 0) {
 delay(100); //wait 0.1 sec after sensor
 prevsensorstate = 1;
 }
 if (digitalRead(inputpin) == LOW && prevsensorstate == 1){ //start playback when status of door sensor changed 
 prevsensorstate = 0;
 sensoractive = 1;
 playAudio();
 sensoractive = 0;
 }
 if (digitalRead(test) == HIGH) {
 prevteststate = 1;
 }
 if (digitalRead(test) == LOW && prevteststate == 1){ //start playback when status of test button changed 
 prevteststate = 0;
 playAudio();
 }

 }
}

void playAudio() { 
 counter++;
// Serial.print("Counter is ");
// Serial.println(counter);
 digitalWrite(led, HIGH); // turn the LED on
 vol = 10; //minimum volume if BCD switch volume is 0
 if (digitalRead(bcd1) == LOW){
 vol = vol + 10;
 }
 if (digitalRead(bcd2) == LOW){
 vol = vol + 20;
 }
 if (digitalRead(bcd4) == LOW){
 vol = vol + 40;
 }
 if (digitalRead(bcd8) == LOW){
 vol = vol + 80;
 }
// Serial.print("Volume is ");
// Serial.println(vol); 
 AudioOutI2S.volume(vol);// adjust the playback volume
 
 if (counter == 1) {
// Serial.println("starting playback file 1");
 waveFile = SDWaveFile(filename1); // start playback 1
 AudioOutI2S.play(waveFile);
 }
 if (counter == 2) {
// Serial.println("starting playback file 2");
 waveFile = SDWaveFile(filename2); // start playback 2
 AudioOutI2S.play(waveFile);
 }
 if (counter == 3) {
// Serial.println("starting playback file 3");
 waveFile = SDWaveFile(filename3); // start playback 3
 AudioOutI2S.play(waveFile);
 }
 if (counter == 4) {
// Serial.println("starting playback file 4");
 waveFile = SDWaveFile(filename4); // start playback 4
 AudioOutI2S.play(waveFile);
 }
 if (counter == 5) {
// Serial.println("starting playback file 5");
 waveFile = SDWaveFile(filename5); // start playback 5
 AudioOutI2S.play(waveFile);
 }
 if (counter == 6) {
// Serial.println("starting playback file 6");
 waveFile = SDWaveFile(filename6); // start playback 6
 AudioOutI2S.play(waveFile);
 counter = 0;
 }
 }
